var indexSectionsWithContent =
{
  0: "abcdefghilmnopqrstuvwx",
  1: "abcfimnopswx",
  2: "mqsw",
  3: "abcdefghilmnoprstvwx",
  4: "abcdefhimnoprstuvwx",
  5: "x",
  6: "sx"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "functions",
  4: "variables",
  5: "groups",
  6: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Functions",
  4: "Variables",
  5: "Modules",
  6: "Pages"
};

